# tuneout: The Open-Source Music Sharing Tool
![PyPI](https://img.shields.io/pypi/v/tuneout?color=blue)
[![GitHub license](https://img.shields.io/github/license/kaangiray26/tuneout)](https://github.com/kaangiray26/tuneout/blob/main/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/kaangiray26/tuneout)](https://github.com/kaangiray26/tuneout/issues)

## PyPI
https://pypi.org/project/tuneout/

## Installation
```
pip install tuneout